/*
 * LogonGroupEditor.h - a dialog for editing logon groups
 *
 * Copyright (c) 2010 Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>
 *
 * This file is part of iTALC - http://italc.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program (see COPYING); if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */

#ifndef LOGON_GROUP_EDITOR_H
#define LOGON_GROUP_EDITOR_H

#include <QDialog>

namespace Ui { class LogonGroupEditor; } ;

class LogonGroupEditor : public QDialog
{
	Q_OBJECT
public:
	LogonGroupEditor( QWidget *parent );
	virtual ~LogonGroupEditor();

	virtual void accept();


private slots:
	void addLogonGroup();
	void removeLogonGroup();


private:
	void updateLogonGroupsUI();

	Ui::LogonGroupEditor *ui;

	QStringList m_logonGroups;

} ;

#endif
